# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buildinfo/rpc/rpc.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='buildinfo/rpc/rpc.proto',
  package='buildinfo.rpc',
  syntax='proto3',
  serialized_options=b'Z,github.com/textileio/powergate/buildinfo/rpc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17\x62uildinfo/rpc/rpc.proto\x12\rbuildinfo.rpc\"\x12\n\x10\x42uildInfoRequest\"\x88\x01\n\x11\x42uildInfoResponse\x12\x12\n\ngit_commit\x18\x01 \x01(\t\x12\x12\n\ngit_branch\x18\x02 \x01(\t\x12\x11\n\tgit_state\x18\x03 \x01(\t\x12\x13\n\x0bgit_summary\x18\x04 \x01(\t\x12\x12\n\nbuild_date\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t2^\n\nRPCService\x12P\n\tBuildInfo\x12\x1f.buildinfo.rpc.BuildInfoRequest\x1a .buildinfo.rpc.BuildInfoResponse\"\x00\x42.Z,github.com/textileio/powergate/buildinfo/rpcb\x06proto3'
)




_BUILDINFOREQUEST = _descriptor.Descriptor(
  name='BuildInfoRequest',
  full_name='buildinfo.rpc.BuildInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=60,
)


_BUILDINFORESPONSE = _descriptor.Descriptor(
  name='BuildInfoResponse',
  full_name='buildinfo.rpc.BuildInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='git_commit', full_name='buildinfo.rpc.BuildInfoResponse.git_commit', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='git_branch', full_name='buildinfo.rpc.BuildInfoResponse.git_branch', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='git_state', full_name='buildinfo.rpc.BuildInfoResponse.git_state', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='git_summary', full_name='buildinfo.rpc.BuildInfoResponse.git_summary', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build_date', full_name='buildinfo.rpc.BuildInfoResponse.build_date', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='buildinfo.rpc.BuildInfoResponse.version', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=199,
)

DESCRIPTOR.message_types_by_name['BuildInfoRequest'] = _BUILDINFOREQUEST
DESCRIPTOR.message_types_by_name['BuildInfoResponse'] = _BUILDINFORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BuildInfoRequest = _reflection.GeneratedProtocolMessageType('BuildInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _BUILDINFOREQUEST,
  '__module__' : 'buildinfo.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:buildinfo.rpc.BuildInfoRequest)
  })
_sym_db.RegisterMessage(BuildInfoRequest)

BuildInfoResponse = _reflection.GeneratedProtocolMessageType('BuildInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _BUILDINFORESPONSE,
  '__module__' : 'buildinfo.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:buildinfo.rpc.BuildInfoResponse)
  })
_sym_db.RegisterMessage(BuildInfoResponse)


DESCRIPTOR._options = None

_RPCSERVICE = _descriptor.ServiceDescriptor(
  name='RPCService',
  full_name='buildinfo.rpc.RPCService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=201,
  serialized_end=295,
  methods=[
  _descriptor.MethodDescriptor(
    name='BuildInfo',
    full_name='buildinfo.rpc.RPCService.BuildInfo',
    index=0,
    containing_service=None,
    input_type=_BUILDINFOREQUEST,
    output_type=_BUILDINFORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RPCSERVICE)

DESCRIPTOR.services_by_name['RPCService'] = _RPCSERVICE

# @@protoc_insertion_point(module_scope)
